@@ -3,11 +3,26 @@ package WebService::Chroma::UA;
 use Moo;
 use LWP::UserAgent;
 use JSON;
+use Module::Load;
 
 has base_url => (
 	is => 'ro',
 );
 
+has embeddings_class => (
+	is => 'ro',
+	trigger => sub {
+		return unless $_[1];
+		my $class = 'WebService::Chroma::Embeddings::' . $_[1];
+		load $class;
+		$_[0]->embeddings($class->new());
+	}
+);
+
+has embeddings => (
+	is => 'rw',
+);
+
 has ua => (
 	is => 'ro',
 	default => sub {
